
server default {
    listen {
        type = auth
        ipv4addr = *
        port = {{config.sites.default.listen.auth.v4.port|safe}}
    #	interface = eth0
        limit {
              max_connections = {{config.sites.default.listen.auth.v4.limit.max_connections|safe}}
              lifetime = {{config.sites.default.listen.auth.v4.limit.lifetime|safe}}
              idle_timeout = {{config.sites.default.listen.auth.v4.limit.idle_timeout|safe}}
        }
    }

    listen {
        type = auth
        ipv6addr = ::
        port = {{config.sites.default.listen.auth.v6.port|safe}}
    #	interface = eth0
        limit {
              max_connections = 16
              lifetime = 0
              idle_timeout = 30
        }
    }

    authorize {
        filter_username
        preprocess
    #	auth_log
        mschap

        #
        #  If you have a Cisco SIP server authenticating against
        #  FreeRADIUS, uncomment the following line, and the 'digest'
        #  line in the 'authenticate' section.
        digest

        #
        #  The WiMAX specification says that the Calling-Station-Id
        #  is 6 octets of the MAC.  This definition conflicts with
        #  RFC 3580, and all common RADIUS practices.  Un-commenting
        #  the "wimax" module here means that it will fix the
        #  Calling-Station-Id attribute to the normal format as
        #  specified in RFC 3580 Section 3.21
    #	wimax

        #
        #  Look for IPASS style 'realm/', and if not found, look for
        #  '@realm', and decide whether or not to proxy, based on
        #  that.
    #	IPASS

        #
        #  If you are using multiple kinds of realms, you probably
        #  want to set "ignore_null = yes" for all of them.
        #  Otherwise, when the first style of realm doesn't match,
        #  the other styles won't be checked.
        #
        suffix
    #	ntdomain

        if(!EAP-Message){
            {% if config.method.macaddr %}# enable mac-auth
            if(&Calling-Station-Id){
                # Calling-Station-Id is available
                if(Calling-Station-Id =~ /^${policy.mac-addr-regexp}$/i){
                    rewrite_calling_station_id
                    authorized_macs
                    if(!ok){
                        reject
                    }
                    else{
                        update control {
                            Auth-Type := Accept
                        }
                    }
                }
            }
            else{
                # Calling-Station-Id is not available
                if(User-Name =~ /^${policy.mac-addr-regexp}$/i){
                    rewrite_user_name
                    authorized_macs_with_user_name
                    if(!ok){
                        reject
                    }
                    else{
                        update control {
                            Auth-Type := Accept
                        }
                    }
                }
            }
            {% else %}# disable mac-auth
            {% endif %}
        }
        else{
            eap {
                ok = return
            }
        }

        files
        expiration
        logintime
        pap

        #
        #  If "status_server = yes", then Status-Server messages are passed
        #  through the following section, and ONLY the following section.
        #  This permits you to do DB queries, for example.  If the modules
        #  listed here return "fail", then NO response is sent.
        #
    #	Autz-Type Status-Server {
    #
    #	}
    }

    authenticate {
        Auth-Type PAP {
            pap
        }
        Auth-Type MS-CHAP {
            mschap
        }
        mschap
        digest
        eap
    }

    session {
    #	radutmp
    }

    post-auth {
        #
        #  If you need to have a State attribute, you can
        #  add it here.  e.g. for later CoA-Request with
        #  State, and Service-Type = Authorize-Only.
        #
    #	if (!&reply:State) {
    #		update reply {
    #			State := "0x%{randstr:16h}"
    #		}
    #	}

        update {
            &reply: += &session-state:
        }

    #	main_pool
    #	reply_log
        exec
    #	wimax

        #  If there is a client certificate (EAP-TLS, sometimes PEAP
        #  and TTLS), then some attributes are filled out after the
        #  certificate verification has been performed.  These fields
        #  MAY be available during the authentication, or they may be
        #  available only in the "post-auth" section.
        #
        #  The first set of attributes contains information about the
        #  issuing certificate which is being used.  The second
        #  contains information about the client certificate (if
        #  available).
    #
    #	update reply {
    #	       Reply-Message += "%{TLS-Cert-Serial}"
    #	       Reply-Message += "%{TLS-Cert-Expiration}"
    #	       Reply-Message += "%{TLS-Cert-Subject}"
    #	       Reply-Message += "%{TLS-Cert-Issuer}"
    #	       Reply-Message += "%{TLS-Cert-Common-Name}"
    #	       Reply-Message += "%{TLS-Cert-Subject-Alt-Name-Email}"
    #
    #	       Reply-Message += "%{TLS-Client-Cert-Serial}"
    #	       Reply-Message += "%{TLS-Client-Cert-Expiration}"
    #	       Reply-Message += "%{TLS-Client-Cert-Subject}"
    #	       Reply-Message += "%{TLS-Client-Cert-Issuer}"
    #	       Reply-Message += "%{TLS-Client-Cert-Common-Name}"
    #	       Reply-Message += "%{TLS-Client-Cert-Subject-Alt-Name-Email}"
    #	}

        #  MacSEC requires the use of EAP-Key-Name.  However, we don't
        #  want to send it for all EAP sessions.  Therefore, the EAP
        #  modules put required data into the EAP-Session-Id attribute.
        #  This attribute is never put into a request or reply packet.
        #
        #  Uncomment the next few lines to copy the required data into
        #  the EAP-Key-Name attribute
    #	if (&reply:EAP-Session-Id) {
    #		update reply {
    #			EAP-Key-Name := &reply:EAP-Session-Id
    #		}
    #	}

        remove_reply_message_if_eap

        Post-Auth-Type REJECT {
            attr_filter.access_reject
            eap
            remove_reply_message_if_eap
            python_post_auth_reject
        }

        Post-Auth-Type Challenge {
    #		remove_reply_message_if_eap
    #		attr_filter.access_challenge.post-auth
        }
        python_post_auth_accept
    }
}
